@@ -33,9 +33,6 @@
 #endif
 
 /* AutoInit dependencies.  */
-#include "vtkFiltersHybridModule.h"
-#include "vtkIOGeometryModule.h"
 #include "vtkIOImageModule.h"
-#include "vtkRenderingCoreModule.h"
 
 #endif
