@@ -38,8 +38,8 @@ cmake .. -G "Ninja" \
     -DBUILD_TESTING:BOOL=OFF \
     -DBUILD_EXAMPLES:BOOL=OFF \
     -DBUILD_SHARED_LIBS:BOOL=ON \
-    -DVTK_ENABLE_VTKPYTHON:BOOL=OFF \
     -DVTK_WRAP_PYTHON:BOOL=ON \
+    -DModule_vtkPythonInterpreter:BOOL=OFF \
     -DVTK_PYTHON_VERSION:STRING="${PY_VER}" \
     -DVTK_INSTALL_PYTHON_MODULE_DIR:PATH="${SP_DIR}" \
     -DVTK_HAS_FEENABLEEXCEPT:BOOL=OFF \
@@ -54,6 +54,7 @@ cmake .. -G "Ninja" \
     -DVTK_USE_SYSTEM_EXPAT:BOOL=ON \
     -DVTK_USE_SYSTEM_HDF5:BOOL=ON \
     -DVTK_USE_SYSTEM_JSONCPP:BOOL=ON \
+    -DVTK_SMP_IMPLEMENTATION_TYPE:STRING=TBB \
     ${SCREEN_ARGS[@]} ${WITH_OSMESA[@]}
 
 # compile & install!
