@@ -64,7 +64,6 @@ from .vtkIOCore import *
 from .vtkIOLegacy import *
 from .vtkIOXMLParser import *
 from .vtkDomainsChemistry import *
-from .vtkIOImage import *
 from .vtkRenderingOpenGL2 import *
 from .vtkDomainsChemistryOpenGL2 import *
 from .vtkIOXML import *
@@ -86,7 +85,9 @@ from .vtkFiltersPython import *
 from .vtkFiltersSMP import *
 from .vtkFiltersSelection import *
 from .vtkFiltersTexture import *
+from .vtkFiltersTopology import *
 from .vtkFiltersVerdict import *
+from .vtkIOImage import *
 from .vtkImagingHybrid import *
 from .vtkInfovisLayout import *
 from .vtkInteractionStyle import *
@@ -101,6 +102,7 @@ from .vtkIOEnSight import *
 from .vtkIOExodus import *
 from .vtkRenderingGL2PSOpenGL2 import *
 from .vtkIOExport import *
+from .vtkIOExportOpenGL2 import *
 from .vtkIOGeometry import *
 from .vtkIOImport import *
 from .vtkIOInfovis import *
@@ -145,8 +147,6 @@ __vtkTypeNameDict = {VTK_VOID:"void",
                      VTK_SIGNED_CHAR:"signed char",
                      VTK_LONG_LONG:"long long",
                      VTK_UNSIGNED_LONG_LONG:"unsigned long long",
-                     VTK___INT64:"__int64",
-                     VTK_UNSIGNED___INT64:"unsigned __int64",
                      VTK_ID_TYPE:"vtkIdType",
                      VTK_BIT:"bit"}
 
